pub struct PyAlgebraicExtension { /* private fields */ }Expand description
An algebraic number field $K = \mathbb{Q}(\alpha)$ defined by a monic minimal polynomial with rational coefficients.
The minimal polynomial is given as a list of coefficients in ascending
degree order; the leading (last) coefficient must be 1. For example,
AlgebraicExtension([-2, 0, 1]) defines $\alpha^2 - 2$ (i.e. $\mathbb{Q}(\sqrt{2})$).