pub struct PyRationalDomain;Expand description
The rational number domain ℚ.
from ocas import RationalDomain
d = RationalDomain()Trait Implementations
Sourceimpl Clone for PyRationalDomain
impl Clone for PyRationalDomain
Sourcefn clone(&self) -> PyRationalDomain
fn clone(&self) -> PyRationalDomain
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl DerefToPyAny for PyRationalDomain
Sourceimpl<'py> IntoPyObject<'py> for PyRationalDomain
impl<'py> IntoPyObject<'py> for PyRationalDomain
Sourcetype Target = PyRationalDomain
type Target = PyRationalDomain
The Python output type
Sourcetype Output = Bound<'py, <PyRationalDomain as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyRationalDomain as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyRationalDomain
impl PyClass for PyRationalDomain
Sourceimpl PyClassImpl for PyRationalDomain
impl PyClassImpl for PyRationalDomain
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// The rational number domain ℚ.
///
/// ```python
/// from ocas import RationalDomain
/// d = RationalDomain()
/// ```
const RAW_DOC: &'static CStr = /// The rational number domain ℚ. /// /// ```python /// from ocas import RationalDomain /// d = RationalDomain() /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyRationalDomain as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyRationalDomain>
type Layout = <<PyRationalDomain as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyRationalDomain>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for PyRationalDomain
impl PyClassNewTextSignature for PyRationalDomain
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyRationalDomain> for PyClassImplCollector<PyRationalDomain>
impl PyMethods<PyRationalDomain> for PyClassImplCollector<PyRationalDomain>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyRationalDomain
impl PyTypeInfo for PyRationalDomain
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.