pub struct PyDoubleF64 { /* private fields */ }Expand description
Python wrapper for double-precision floating-point arithmetic.
Provides ~31 decimal digits of precision (~84 binary bits) using Dekker/Knuth “double-float” arithmetic.
from ocas import DoubleF64
a = DoubleF64(1.0)
b = DoubleF64(2.0)
print(a + b) # 3.0Trait Implementations
Sourceimpl Clone for PyDoubleF64
impl Clone for PyDoubleF64
Sourcefn clone(&self) -> PyDoubleF64
fn clone(&self) -> PyDoubleF64
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PyDoubleF64
Sourceimpl Debug for PyDoubleF64
impl Debug for PyDoubleF64
impl DerefToPyAny for PyDoubleF64
Sourceimpl<'py> IntoPyObject<'py> for PyDoubleF64
impl<'py> IntoPyObject<'py> for PyDoubleF64
Sourcetype Target = PyDoubleF64
type Target = PyDoubleF64
The Python output type
Sourcetype Output = Bound<'py, <PyDoubleF64 as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyDoubleF64 as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyDoubleF64
impl PyClass for PyDoubleF64
Sourceimpl PyClassImpl for PyDoubleF64
impl PyClassImpl for PyDoubleF64
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Python wrapper for double-precision floating-point arithmetic.
///
/// Provides ~31 decimal digits of precision (~84 binary bits) using
/// Dekker/Knuth "double-float" arithmetic.
///
/// ```python
/// from ocas import DoubleF64
///
/// a = DoubleF64(1.0)
/// b = DoubleF64(2.0)
/// print(a + b) # 3.0
/// ```
const RAW_DOC: &'static CStr = /// Python wrapper for double-precision floating-point arithmetic. /// /// Provides ~31 decimal digits of precision (~84 binary bits) using /// Dekker/Knuth "double-float" arithmetic. /// /// ```python /// from ocas import DoubleF64 /// /// a = DoubleF64(1.0) /// b = DoubleF64(2.0) /// print(a + b) # 3.0 /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyDoubleF64 as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyDoubleF64>
type Layout = <<PyDoubleF64 as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyDoubleF64>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for PyDoubleF64
impl PyClassNewTextSignature for PyDoubleF64
const TEXT_SIGNATURE: &'static str = "(hi, lo=0.0)"
Sourceimpl PyClass__add__SlotFragment<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
impl PyClass__add__SlotFragment<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
Sourceimpl PyClass__mul__SlotFragment<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
impl PyClass__mul__SlotFragment<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
Sourceimpl PyClass__pow__SlotFragment<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
impl PyClass__pow__SlotFragment<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
Sourceimpl PyClass__sub__SlotFragment<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
impl PyClass__sub__SlotFragment<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
Sourceimpl PyClass__truediv__SlotFragment<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
impl PyClass__truediv__SlotFragment<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
Sourceimpl PyMethods<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
impl PyMethods<PyDoubleF64> for PyClassImplCollector<PyDoubleF64>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyDoubleF64
impl PyTypeInfo for PyDoubleF64
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.