pub struct Expression { /* private fields */ }Expand description
A symbolic expression.
Construct from a string:
from ocas import Expression
e = Expression("x^2 + 2*x + 1")
print(e.diff("x"))Trait Implementations
impl DerefToPyAny for Expression
impl ExtractPyClassWithClone for Expression
Sourceimpl<'py> IntoPyObject<'py> for Expression
impl<'py> IntoPyObject<'py> for Expression
Sourcetype Target = Expression
type Target = Expression
The Python output type
Sourcetype Output = Bound<'py, <Expression as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <Expression as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for Expression
impl PyClass for Expression
Sourceimpl PyClassImpl for Expression
impl PyClassImpl for Expression
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// A symbolic expression.
///
/// Construct from a string:
///
/// ```python
/// from ocas import Expression
/// e = Expression("x^2 + 2*x + 1")
/// print(e.diff("x"))
/// ```
const RAW_DOC: &'static CStr = /// A symbolic expression. /// /// Construct from a string: /// /// ```python /// from ocas import Expression /// e = Expression("x^2 + 2*x + 1") /// print(e.diff("x")) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<Expression as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<Expression>
type Layout = <<Expression as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<Expression>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for Expression
impl PyClassNewTextSignature for Expression
const TEXT_SIGNATURE: &'static str = "(input)"
Sourceimpl PyClass__add__SlotFragment<Expression> for PyClassImplCollector<Expression>
impl PyClass__add__SlotFragment<Expression> for PyClassImplCollector<Expression>
Sourceimpl PyClass__eq__SlotFragment<Expression> for PyClassImplCollector<Expression>
impl PyClass__eq__SlotFragment<Expression> for PyClassImplCollector<Expression>
Sourceimpl PyClass__mul__SlotFragment<Expression> for PyClassImplCollector<Expression>
impl PyClass__mul__SlotFragment<Expression> for PyClassImplCollector<Expression>
Sourceimpl PyClass__pow__SlotFragment<Expression> for PyClassImplCollector<Expression>
impl PyClass__pow__SlotFragment<Expression> for PyClassImplCollector<Expression>
Sourceimpl PyClass__sub__SlotFragment<Expression> for PyClassImplCollector<Expression>
impl PyClass__sub__SlotFragment<Expression> for PyClassImplCollector<Expression>
Sourceimpl PyMethods<Expression> for PyClassImplCollector<Expression>
impl PyMethods<Expression> for PyClassImplCollector<Expression>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for Expression
impl PyTypeInfo for Expression
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.