pub struct PyGroebnerBasis {
pub n_vars: usize,
pub basis: Vec<SparseMultivariatePolynomial<RationalDomain, Lex>>,
}Expand description
A Gröbner basis computation result.
Fields
n_vars: usizebasis: Vec<SparseMultivariatePolynomial<RationalDomain, Lex>>Trait Implementations
impl DerefToPyAny for PyGroebnerBasis
impl ExtractPyClassWithClone for PyGroebnerBasis
Sourceimpl<'py> IntoPyObject<'py> for PyGroebnerBasis
impl<'py> IntoPyObject<'py> for PyGroebnerBasis
Sourcetype Target = PyGroebnerBasis
type Target = PyGroebnerBasis
The Python output type
Sourcetype Output = Bound<'py, <PyGroebnerBasis as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyGroebnerBasis as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyGroebnerBasis
impl PyClass for PyGroebnerBasis
Sourceimpl PyClassImpl for PyGroebnerBasis
impl PyClassImpl for PyGroebnerBasis
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// A Gröbner basis computation result.
const RAW_DOC: &'static CStr = /// A Gröbner basis computation result.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyGroebnerBasis as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyGroebnerBasis>
type Layout = <<PyGroebnerBasis as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyGroebnerBasis>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyMethods<PyGroebnerBasis> for PyClassImplCollector<PyGroebnerBasis>
impl PyMethods<PyGroebnerBasis> for PyClassImplCollector<PyGroebnerBasis>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyGroebnerBasis
impl PyTypeInfo for PyGroebnerBasis
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.