pub struct PyMultivariatePolynomial {
pub inner: SparseMultivariatePolynomial<RationalDomain, Lex>,
}Expand description
A multivariate polynomial over $\mathbb{Q}$, constructed from a dictionary mapping exponent tuples to coefficients.
from ocas import MultivariatePolynomial
# x² + y² - 1 in k[x,y]
p = MultivariatePolynomial({(2, 0): 1, (0, 2): 1, (0, 0): -1}, n_vars=2)Fields
inner: SparseMultivariatePolynomial<RationalDomain, Lex>Trait Implementations
impl DerefToPyAny for PyMultivariatePolynomial
impl ExtractPyClassWithClone for PyMultivariatePolynomial
Sourceimpl<'py> IntoPyObject<'py> for PyMultivariatePolynomial
impl<'py> IntoPyObject<'py> for PyMultivariatePolynomial
Sourcetype Target = PyMultivariatePolynomial
type Target = PyMultivariatePolynomial
The Python output type
Sourcetype Output = Bound<'py, <PyMultivariatePolynomial as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyMultivariatePolynomial as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyMultivariatePolynomial
impl PyClass for PyMultivariatePolynomial
Sourceimpl PyClassImpl for PyMultivariatePolynomial
impl PyClassImpl for PyMultivariatePolynomial
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// A multivariate polynomial over $\mathbb{Q}$, constructed from a dictionary
/// mapping exponent tuples to coefficients.
///
/// ```python
/// from ocas import MultivariatePolynomial
///
/// # x² + y² - 1 in k[x,y]
/// p = MultivariatePolynomial({(2, 0): 1, (0, 2): 1, (0, 0): -1}, n_vars=2)
/// ```
const RAW_DOC: &'static CStr = /// A multivariate polynomial over $\mathbb{Q}$, constructed from a dictionary /// mapping exponent tuples to coefficients. /// /// ```python /// from ocas import MultivariatePolynomial /// /// # x² + y² - 1 in k[x,y] /// p = MultivariatePolynomial({(2, 0): 1, (0, 2): 1, (0, 0): -1}, n_vars=2) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyMultivariatePolynomial as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyMultivariatePolynomial>
type Layout = <<PyMultivariatePolynomial as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyMultivariatePolynomial>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for PyMultivariatePolynomial
impl PyClassNewTextSignature for PyMultivariatePolynomial
const TEXT_SIGNATURE: &'static str = "(terms, n_vars)"
Sourceimpl PyMethods<PyMultivariatePolynomial> for PyClassImplCollector<PyMultivariatePolynomial>
impl PyMethods<PyMultivariatePolynomial> for PyClassImplCollector<PyMultivariatePolynomial>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyMultivariatePolynomial
impl PyTypeInfo for PyMultivariatePolynomial
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.