pub fn py_classify_ode(
equation: &Expression,
func: &str,
var: &str,
) -> PyResult<Vec<String>>Expand description
Classify an ODE and return the applicable method names.
equation is the ODE written as an expression equal to zero (e.g.
"Derivative(y(x), x) - y(x)"), func the unknown function name
(e.g. "y"), and var the independent variable (e.g. "x").
Returns a list of method names such as "LinearFirst", "Separable",
"LinearConstantCoeff", etc.